"""
RCK SDK main client class
"""

import logging
from typing import Optional, Dict, Any
from .core.http_client import HTTPClient
from .core.auth import AuthManager
from .compute.kernel import ComputeKernel
from .image.generator import ImageGenerator
from .utils.logger import setup_logger

logger = logging.getLogger(__name__)

class RCKClient:
    """
    RCK Python SDK main client
    
    Provides unified interface to access all RCK API functionality, including:
    - Text computation and analysis
    - Image generation and rendering
    - Multimodal resource processing
    
    Usage example:
        client = RCKClient(api_key="your-api-key")
        
        # Text analysis
        result = client.compute.analyze(
            text="Moonlight before my bed, looks like frost on the ground",
            task="Analyze the emotion and theme of the poetry"
        )
        
        # Image generation
        image = client.image.generate(
            prompt="Landscape in traditional painting style",
            composition="Distant mountains and close water composition",
            lighting="Soft morning light",
            style="Traditional Chinese ink wash painting style"
        )
    """
    
    def __init__(
        self,
        api_key: str,
        base_url: Optional[str] = None,
        timeout: int = 30,
        log_level: int = logging.INFO
    ):
        """
        Initialize RCK client
        
        :param api_key: Topos API key
        :param base_url: API base URL, defaults to official address
        :param timeout: Request timeout (seconds)
        :param log_level: Log level
        """
        # Setup logging
        self.logger = setup_logger("rck_sdk", log_level)
        
        # Initialize authentication manager
        self.auth = AuthManager(api_key)
        
        # Initialize HTTP client
        self.http_client = HTTPClient(
            api_key=api_key,
            base_url=base_url,
            timeout=timeout
        )
        
        # Initialize functional modules
        self.compute = ComputeKernel(self.http_client)
        self.image = ImageGenerator(self.http_client)
        
        self.logger.info("RCK Client initialized successfully")
    
    def set_timeout(self, timeout: int) -> None:
        """
        Set request timeout
        
        :param timeout: Timeout in seconds
        """
        self.http_client.timeout = timeout
        self.logger.info(f"Request timeout set to {timeout} seconds")
    
    def test_connection(self) -> Dict[str, Any]:
        """
        Test connection to API
        
        :return: Connection test result
        """
        try:
            # Execute a simple text analysis test
            result = self.compute.analyze(
                text="test",
                task="simple analysis",
                output_format="basic_analysis"
            )
            
            return {
                "status": "success",
                "message": "Connection normal",
                "test_result": result.data
            }
            
        except Exception as e:
            return {
                "status": "error", 
                "message": f"Connection failed: {str(e)}",
                "test_result": None
            }
    
    def get_client_info(self) -> Dict[str, Any]:
        """
        Get client information
        
        :return: Client configuration information
        """
        return {
            "version": "1.0.1",
            "api_base_url": self.http_client.base_url,
            "timeout": self.http_client.timeout,
            "has_api_key": bool(self.auth.api_key),
            "api_key_valid": self.auth.validate_key()
        }

    # Convenience methods - provide shortcut access to common functionality directly on client
    def analyze_text(
        self,
        text: str,
        task: str = "Analyze text emotion, theme and content",
        **kwargs
    ) -> Dict[str, Any]:
        """
        Convenient text analysis method
        
        :param text: Text to be analyzed
        :param task: Analysis task
        :param kwargs: Other parameters
        :return: Analysis result
        """
        result = self.compute.analyze(text, task, **kwargs)
        return result.data
    
    def generate_image(
        self,
        prompt: str,
        style: str = "Modern digital art style",
        composition: str = "Centered composition, harmonious picture",
        lighting: str = "Natural lighting, bright and clear"
    ) -> 'ImageResponse':
        """
        Convenient image generation method
        
        :param prompt: Image description
        :param style: Artistic style
        :param composition: Composition description
        :param lighting: Lighting description
        :return: Image response object
        """
        return self.image.generate(
            prompt=prompt,
            composition=composition,
            lighting=lighting,
            style=style
        ) 