"""
Text computation core functionality
"""

import logging
from typing import Dict, Any, List, Optional, Union
from ..core.http_client import HTTPClient
from ..models.request import ComputeRequest
from ..models.response import ComputeResponse
from ..utils.validators import validate_string, validate_dict, validate_output_schema
from .schemas import get_schema, PREDEFINED_SCHEMAS

logger = logging.getLogger(__name__)

class ComputeKernel:
    """Text computation core class"""
    
    def __init__(self, http_client: HTTPClient):
        """
        Initialize compute kernel
        
        :param http_client: HTTP client instance
        """
        self.http_client = http_client
    
    def analyze(
        self,
        text: str,
        task: str,
        output_format: Union[str, Dict[str, Any]] = "basic_analysis",
        **kwargs
    ) -> ComputeResponse:
        """
        Text analysis functionality
        
        :param text: Text to be analyzed
        :param task: Analysis task description
        :param output_format: Output format, can be predefined format name or custom Schema
        :param kwargs: Other custom parameters
        :return: Analysis result
        """
        validate_string(text, "text")
        validate_string(task, "task")
        
        # Handle output format
        if isinstance(output_format, str):
            if output_format in PREDEFINED_SCHEMAS:
                schema = get_schema(output_format)
            else:
                raise ValueError(f"Unknown predefined format: {output_format}")
        else:
            schema = output_format
            validate_output_schema(schema)
        
        # Create request
        request = ComputeRequest(
            start_point=text,
            expect_path=task,
            output_schema=schema,
            custom_fields=kwargs
        )
        
        logger.info(f"Executing text analysis: {task[:50]}...")
        
        # Send request
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        
        # Return response
        return ComputeResponse(response_data.get("end_point", {}))
    
    def create_poem(
        self,
        inspiration: str,
        style: str = "five-character quatrain",
        resources: Optional[List[Dict[str, str]]] = None
    ) -> ComputeResponse:
        """
        Poetry creation functionality
        
        :param inspiration: Creative inspiration or theme
        :param style: Poetry style
        :param resources: Multimodal resources (like images)
        :return: Creation result
        """
        task = f"Create a {style} based on the given inspiration and explain the creative process"
        
        request = ComputeRequest(
            start_point=inspiration,
            expect_path=task,
            output_schema=get_schema("poem_creation"),
            custom_fields={"style": style},
            resources=resources
        )
        
        logger.info(f"Executing poetry creation: {style}")
        
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        return ComputeResponse(response_data.get("end_point", {}))
    
    def translate(
        self,
        text: str,
        target_language: str,
        include_cultural_notes: bool = True
    ) -> ComputeResponse:
        """
        Text translation functionality
        
        :param text: Text to be translated
        :param target_language: Target language
        :param include_cultural_notes: Whether to include cultural background notes
        :return: Translation result
        """
        if include_cultural_notes:
            task = f"Translate text to {target_language} and provide cultural background notes"
        else:
            task = f"Translate text to {target_language}"
        
        request = ComputeRequest(
            start_point=text,
            expect_path=task,
            output_schema=get_schema("translation"),
            custom_fields={
                "target_language": target_language,
                "include_cultural_notes": str(include_cultural_notes)
            }
        )
        
        logger.info(f"Executing translation: target language {target_language}")
        
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        return ComputeResponse(response_data.get("end_point", {}))
    
    def custom_compute(
        self,
        text: str,
        task: str,
        output_schema: Optional[Dict[str, Any]] = None,
        resources: Optional[List[Dict[str, str]]] = None,
        **custom_fields
    ) -> ComputeResponse:
        """
        Custom computation functionality, providing maximum flexibility
        
        :param text: Input text
        :param task: Task description
        :param output_schema: Custom output format
        :param resources: Multimodal resources
        :param custom_fields: Custom fields
        :return: Computation result
        """
        request = ComputeRequest(
            start_point=text,
            expect_path=task,
            output_schema=output_schema,
            custom_fields=custom_fields,
            resources=resources
        )
        
        logger.info(f"Executing custom computation: {task[:50]}...")
        
        response_data = self.http_client.post("/compute/execute", request.to_dict())
        return ComputeResponse(response_data.get("end_point", {})) 