"""
HTTP client wrapper, handles all communication with RCK API
"""

import requests
import logging
from typing import Dict, Any, Optional, List
from .exceptions import APIError, NetworkError, TimeoutError, AuthenticationError

logger = logging.getLogger(__name__)

class HTTPClient:
    """RCK API HTTP client"""
    
    def __init__(self, api_key: str, base_url: str = None, timeout: int = 30):
        """
        Initialize HTTP client
        
        :param api_key: Topos API key
        :param base_url: API base URL
        :param timeout: Request timeout (seconds)
        """
        self.api_key = api_key
        self.base_url = base_url or "https://relatioe-kernel-zdibtqjzxm.us-west-1.fcapp.run"
        self.timeout = timeout
        
        # Default request headers
        self.default_headers = {
            "topos-api-key": api_key,
            "Content-Type": "application/json",
            "User-Agent": "RCK-Python-SDK/1.0.0"
        }
    
    def request(
        self,
        method: str,
        endpoint: str,
        data: Dict[str, Any] = None,
        headers: Dict[str, str] = None
    ) -> Dict[str, Any]:
        """
        Send HTTP request
        
        :param method: HTTP method
        :param endpoint: API endpoint
        :param data: Request data
        :param headers: Additional request headers
        :return: Response data
        """
        url = f"{self.base_url}{endpoint}"
        
        # Merge request headers
        request_headers = self.default_headers.copy()
        if headers:
            request_headers.update(headers)
        
        logger.debug(f"Sending {method} request to: {url}")
        logger.debug(f"Request data: {data}")
        
        try:
            response = requests.request(
                method=method,
                url=url,
                json=data,
                headers=request_headers,
                timeout=self.timeout
            )
            
            logger.debug(f"Response status: {response.status_code}")
            logger.debug(f"Response body: {response.text}")
            
            # Handle HTTP error status codes
            if response.status_code == 401:
                raise AuthenticationError("Invalid or expired API key")
            elif response.status_code == 403:
                raise AuthenticationError("Insufficient permissions, please check API key permissions")
            elif response.status_code >= 400:
                try:
                    error_data = response.json()
                    error_message = error_data.get('error', f"API request failed: {response.status_code}")
                except:
                    error_message = f"API request failed: {response.status_code}"
                
                raise APIError(
                    error_message,
                    status_code=response.status_code,
                    response_data=error_data if 'error_data' in locals() else None
                )
            
            # Parse response
            response_data = response.json()
            return response_data
            
        except requests.exceptions.Timeout:
            raise TimeoutError(f"Request timeout ({self.timeout} seconds)")
        except requests.exceptions.ConnectionError:
            raise NetworkError("Network connection failed, please check network status")
        except requests.exceptions.RequestException as e:
            raise NetworkError(f"Network request failed: {str(e)}")
    
    def post(self, endpoint: str, data: Dict[str, Any] = None) -> Dict[str, Any]:
        """Send POST request"""
        return self.request("POST", endpoint, data)
    
    def get(self, endpoint: str) -> Dict[str, Any]:
        """Send GET request"""
        return self.request("GET", endpoint) 