"""
Image generation core functionality
"""

import logging
from typing import Optional, List
from ..core.http_client import HTTPClient
from ..models.request import ImageRequest
from ..models.response import ImageResponse
from ..utils.validators import validate_string
from .utils import validate_image_params, save_images

logger = logging.getLogger(__name__)

class ImageGenerator:
    """Image generation core class"""
    
    def __init__(self, http_client: HTTPClient):
        """
        Initialize image generator
        
        :param http_client: HTTP client instance
        """
        self.http_client = http_client
    
    def generate(
        self,
        prompt: str,
        composition: str,
        lighting: str,
        style: str
    ) -> ImageResponse:
        """
        Generate image
        
        :param prompt: Image description prompt
        :param composition: Composition description
        :param lighting: Lighting description
        :param style: Artistic style description
        :return: Image generation result
        """
        # Parameter validation
        validate_string(prompt, "prompt")
        validate_image_params(composition, lighting, style)
        
        # Create request
        request = ImageRequest(
            start_point=prompt,
            composition=composition,
            lighting=lighting,
            style=style
        )
        
        logger.info(f"Starting image generation: {prompt[:50]}...")
        logger.debug(f"Style: {style[:30]}...")
        
        # Send request
        response_data = self.http_client.post("/sd2is/render", request.to_dict())
        
        # Parse response
        image_response = ImageResponse.from_dict(response_data.get("end_point", {}))
        
        logger.info(f"Image generation completed: {image_response.count} images")
        
        return image_response
    
    def generate_from_mermaid(
        self,
        mermaid_diagram: str,
        composition: str,
        lighting: str, 
        style: str
    ) -> ImageResponse:
        """
        Generate image from Mermaid diagram
        
        :param mermaid_diagram: Mermaid diagram description
        :param composition: Composition description
        :param lighting: Lighting description
        :param style: Artistic style description
        :return: Image generation result
        """
        return self.generate(
            prompt=mermaid_diagram,
            composition=composition,
            lighting=lighting,
            style=style
        )
    
    def generate_art_styles(
        self,
        prompt: str,
        styles: List[str],
        composition: str = "Classic composition, harmonious and balanced",
        lighting: str = "Natural lighting, soft and bright"
    ) -> List[ImageResponse]:
        """
        Generate images in multiple artistic styles
        
        :param prompt: Image description prompt
        :param styles: List of artistic styles
        :param composition: Composition description
        :param lighting: Lighting description
        :return: Multiple image generation results
        """
        results = []
        
        for style in styles:
            logger.info(f"Generating {style} style image...")
            try:
                result = self.generate(
                    prompt=prompt,
                    composition=composition,
                    lighting=lighting,
                    style=style
                )
                results.append(result)
            except Exception as e:
                logger.error(f"Failed to generate {style} style image: {e}")
        
        return results
    
    def save_images(
        self,
        image_response: ImageResponse,
        base_filename: str = "generated",
        output_dir: str = "."
    ) -> List[str]:
        """
        Save images to local files
        
        :param image_response: Image response object
        :param base_filename: Base filename
        :param output_dir: Output directory
        :return: List of saved file paths
        """
        return save_images(image_response, base_filename, output_dir)
 