"""
Image processing utility functions
"""

import base64
import logging
from typing import List, Optional
from ..models.response import ImageResponse, ImageInfo

logger = logging.getLogger(__name__)

def save_images(
    image_response: ImageResponse,
    base_filename: str = "generated",
    output_dir: str = "."
) -> List[str]:
    """
    Save images to local files
    
    :param image_response: Image response object
    :param base_filename: Base filename
    :param output_dir: Output directory
    :return: List of saved file paths
    """
    import os
    import requests
    
    saved_files = []
    
    if not image_response.success:
        logger.warning("Image response is not successful, cannot save")
        return saved_files
    
    # Ensure output directory exists
    if not os.path.exists(output_dir):
        os.makedirs(output_dir)
    
    logger.info(f"Starting to save {len(image_response.images)} images...")
    
    for i, image_info in enumerate(image_response.images):
        try:
            # Get image data
            if image_info.image_data:
                # Base64 decode
                image_data = base64.b64decode(image_info.image_data)
            elif image_info.url:
                # Download from URL
                response = requests.get(image_info.url)
                response.raise_for_status()
                image_data = response.content
            else:
                logger.warning(f"Image {i} has no available data source")
                continue
            
            # Determine file extension
            ext = _get_file_extension(image_info.mime_type)
            
            # Generate filename
            if len(image_response.images) == 1:
                filename = f"{base_filename}.{ext}"
            else:
                filename = f"{base_filename}_{i + 1}.{ext}"
            
            filepath = os.path.join(output_dir, filename)
            
            # Save file
            with open(filepath, 'wb') as f:
                f.write(image_data)
            
            saved_files.append(filepath)
            logger.info(f"✅ Image {i + 1} saved: {filepath} ({len(image_data)} bytes)")
            
        except Exception as e:
            logger.error(f"❌ Failed to save image {i + 1}: {e}")
    
    logger.info(f"Successfully saved {len(saved_files)} images")
    return saved_files

def _get_file_extension(mime_type: str) -> str:
    """Determine file extension based on MIME type"""
    mime_to_ext = {
        'image/png': 'png',
        'image/jpeg': 'jpg',
        'image/jpg': 'jpg', 
        'image/webp': 'webp',
        'image/gif': 'gif',
        'image/bmp': 'bmp'
    }
    
    return mime_to_ext.get(mime_type.lower(), 'png')

def validate_image_params(composition: str, lighting: str, style: str) -> None:
    """Validate image generation parameters"""
    from ..utils.validators import validate_string
    
    validate_string(composition, "composition", max_length=500)
    validate_string(lighting, "lighting", max_length=300)
    validate_string(style, "style", max_length=300)