"""
Response data models
"""

from typing import Dict, Any, List, Optional
from dataclasses import dataclass

@dataclass
class ComputeResponse:
    """Text computation response model"""
    raw_data: Dict[str, Any]
    
    @property
    def data(self) -> Dict[str, Any]:
        """Get response data"""
        return self.raw_data
    
    def get(self, key: str, default: Any = None) -> Any:
        """Get value of specific field"""
        return self.raw_data.get(key, default)
    
    def __getitem__(self, key: str) -> Any:
        """Support dictionary-style access"""
        return self.raw_data[key]
    
    def __contains__(self, key: str) -> bool:
        """Support 'in' operator"""
        return key in self.raw_data
    
    def keys(self):
        """Get all keys"""
        return self.raw_data.keys()
    
    def values(self):
        """Get all values"""
        return self.raw_data.values()
    
    def items(self):
        """Get all key-value pairs"""
        return self.raw_data.items()

@dataclass
class ImageInfo:
    """Single image information"""
    url: Optional[str] = None
    image_data: Optional[str] = None
    index: int = 0
    size: int = 0
    mime_type: str = "image/png"
    
    @classmethod
    def from_dict(cls, data: Dict[str, Any]) -> 'ImageInfo':
        """Create ImageInfo object from dictionary"""
        return cls(
            url=data.get('url'),
            image_data=data.get('imageData'),
            index=data.get('index', 0),
            size=data.get('size', 0),
            mime_type=data.get('mimeType', 'image/png')
        )
    
    @property
    def has_data(self) -> bool:
        """Check if image data is available"""
        return bool(self.url or self.image_data)

@dataclass
class ImageResponse:
    """Image generation response model"""
    images: List[ImageInfo]
    count: int
    status: str
    raw_data: Dict[str, Any]
    
    @classmethod
    def from_dict(cls, data: Dict[str, Any]) -> 'ImageResponse':
        """Create ImageResponse object from API response"""
        images_data = data.get('images', [])
        images = [ImageInfo.from_dict(img) for img in images_data]
        
        return cls(
            images=images,
            count=data.get('count', len(images)),
            status=data.get('status', 'success'),
            raw_data=data
        )
    
    @property
    def success(self) -> bool:
        """Check if request was successful"""
        return self.status == 'success' and self.count > 0
    
    def __len__(self) -> int:
        """Support len() function"""
        return len(self.images)
    
    def __getitem__(self, index: int) -> ImageInfo:
        """Support index access"""
        return self.images[index]
    
    def __iter__(self):
        """Support iteration"""
        return iter(self.images)