"""
Parameter validation utilities
"""

from typing import Any, Dict, List, Optional, Union
from ..core.exceptions import ValidationError

def validate_required(value: Any, field_name: str) -> None:
    """Validate required field"""
    if value is None or value == "":
        raise ValidationError(f"Field '{field_name}' is required", field_name)

def validate_string(value: Any, field_name: str, max_length: Optional[int] = None) -> None:
    """Validate string field"""
    validate_required(value, field_name)
    
    if not isinstance(value, str):
        raise ValidationError(f"Field '{field_name}' must be string type", field_name)
    
    if max_length and len(value) > max_length:
        raise ValidationError(f"Field '{field_name}' length cannot exceed {max_length} characters", field_name)

def validate_dict(value: Any, field_name: str) -> None:
    """Validate dictionary field"""
    validate_required(value, field_name)
    
    if not isinstance(value, dict):
        raise ValidationError(f"Field '{field_name}' must be dictionary type", field_name)

def validate_list(value: Any, field_name: str, min_length: Optional[int] = None) -> None:
    """Validate list field"""
    validate_required(value, field_name)
    
    if not isinstance(value, list):
        raise ValidationError(f"Field '{field_name}' must be list type", field_name)
    
    if min_length and len(value) < min_length:
        raise ValidationError(f"Field '{field_name}' requires at least {min_length} elements", field_name)

def validate_output_schema(schema: Dict[str, Any]) -> None:
    """Validate output format schema"""
    validate_dict(schema, "output_schema")
    
    if "type" not in schema:
        raise ValidationError("output_schema must contain 'type' field", "output_schema")
    
    if schema["type"] != "object":
        raise ValidationError("output_schema 'type' must be 'object'", "output_schema")
    
    if "properties" not in schema:
        raise ValidationError("output_schema must contain 'properties' field", "output_schema") 